# FeedIndicator

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**expiration_source** | [**ExpirationSource**](ExpirationSource.md) |  | [optional] 
**bypass_exclusion_list** | **bool** |  | [optional] 
**classifier_version** | **int** |  | [optional] 
**expiration_interval** | **int** |  | [optional] 
**expiration_policy** | [**ExpirationPolicy**](ExpirationPolicy.md) |  | [optional] 
**feed_config** | **dict(str, object)** |  | [optional] 
**fetch_time** | **datetime** |  | [optional] 
**fields** | [**CustomFields**](CustomFields.md) |  | [optional] 
**is_enrichment** | **bool** |  | [optional] 
**modified_time** | **datetime** |  | [optional] 
**module_id** | **str** |  | [optional] 
**raw_json** | **dict(str, object)** |  | [optional] 
**reliability** | [**Reliability**](Reliability.md) |  | [optional] 
**score** | **int** |  | [optional] 
**source_brand** | **str** |  | [optional] 
**source_instance** | **str** |  | [optional] 
**timestamp** | **datetime** |  | [optional] 
**type** | **str** | indicator fields | [optional] 
**value** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


